//CODE HEM_Programmable_Sequencer_C******
///////////////////
//This code adds speed control knob to the stepping logic and in internal
//oscillator of the previous sketch
///////////////////

//Set up an ARRAY:
//every time the program sees the word "steps[x]" it will
//replace it with the "x" number in the list.
//e.g. from the array below: steps[0] = 9, steps[1] = 8, steps[6] = 3, etc
int steps[8] = {9, 8, 7, 6, 5, 4, 3, 2};  //the numbers represent the Arduino Digital Pins

int stepTime = 200; //the word stepTime will be replaced by the number 200 - change this to change speed
int speedKnob = A2; //center pin of Speed knob is attached to pin A0
int mappedSpeed;    //variable used to store a scaled version of the analog reading of the speed knob
int stepNum = 0;    //this variable will keep track of which step is turned on.

int CVPin = A5;     //Analog Input Pin to read CV
int tonePin = 13;   //Output pin to produce tone
int note;

//The setup() is the first block of instructions that Arduino runs
//It happens one time when the hardware is first powered on
//Your sketch must have one and only one setup
void setup() {
  pinMode(steps[0], OUTPUT); //configure pin 9 as an output
  pinMode(steps[1], OUTPUT); //configure pin 8 as an output
  pinMode(steps[2], OUTPUT); //configure pin 7 as an output
  pinMode(steps[3], OUTPUT);
  pinMode(steps[4], OUTPUT);
  pinMode(steps[5], OUTPUT);
  pinMode(steps[6], OUTPUT);
  pinMode(steps[7], OUTPUT);
}

//the  loop runs through each instruction, one at a time until it gets to the end.
//then it loops back up to the top and does it again
void loop() {

  if (stepNum > 7) {
    stepNum = 0;  //"0" is the frist note, "1" is the second, and so on
  }

  //Read the voltage on knob A0 and store the number (something between 0 and 1023) in the variable "stepTime"
  stepTime = analogRead(speedKnob); //stepTime and speedKnob are variables declared before the setup()

  //scale the stepTime variable to a new range that also reverses the direction so the min is higher than the max
  //0 - 1023 are the min and max of the actual reading, 300 and 1 are the new min and max representing delay times in ms
  mappedSpeed = map(stepTime, 0, 1023, 300, 1);

  //this is where the step gets turned on, the code paused, and then the step turned off again
  digitalWrite(steps[stepNum], HIGH); //toggle selected pin (stepNum[0] = 9) to 5v (step 1 turns on)
  //get value of CV from pin A5
  //Note: the (void) and the delay are there to deal with ghost voltages
  //resulting from multiplexing of the ADC and the unbuffered circuitry.
  //This problem could also be solved with additonal circuitry
  (void)analogRead(CVPin);
  delay(8);
  note = map(analogRead(CVPin), 0, 1023, 35, 1200);     //get frequency value by reading the A5 pin
  tone(tonePin, note);                //write the note to the audio out
  delay(mappedSpeed);                 //pause code for the amount of time set by the knob (milliseconds)
  noTone(tonePin);
  digitalWrite(steps[stepNum], LOW);  //toggle selected pin to 0v (step 1 turns off)

  stepNum ++;  //increment stepNum up by one

}
//**********END OF CODE
